@@ -1,21 +1,21 @@
 import typing
-from dataclasses import dataclass, field
 from datetime import datetime
 
+from pydantic import BaseModel, Field
+
 from flag_engine.environments.integrations.models import IntegrationModel
 from flag_engine.features.models import FeatureStateModel
 from flag_engine.projects.models import ProjectModel
 from flag_engine.utils.datetime import utcnow_with_tz
 
 
-@dataclass
-class EnvironmentAPIKeyModel:
+class EnvironmentAPIKeyModel(BaseModel):
     id: int
     key: str
     created_at: datetime
     name: str
     client_api_key: str
-    expires_at: datetime = None
+    expires_at: typing.Optional[datetime] = None
     active: bool = True
 
     @property
@@ -25,50 +25,50 @@ class EnvironmentAPIKeyModel:
         )
 
 
-@dataclass
-class WebhookModel:
+class WebhookModel(BaseModel):
     url: str
     secret: str
 
 
-@dataclass
-class EnvironmentModel:
+class EnvironmentModel(BaseModel):
     id: int
     api_key: str
     project: ProjectModel
-    feature_states: typing.List[FeatureStateModel] = field(default_factory=list)
+    feature_states: typing.List[FeatureStateModel] = Field(default_factory=list)
 
-    name: str = None
+    name: typing.Optional[str] = None
     allow_client_traits: bool = True
-    updated_at: datetime = field(default_factory=utcnow_with_tz)
-    use_mv_v2_evaluation: bool = False
+    updated_at: datetime = Field(default_factory=utcnow_with_tz)
     hide_sensitive_data: bool = False
+    hide_disabled_flags: typing.Optional[bool] = None
+    use_identity_composite_key_for_hashing: bool = False
 
-    amplitude_config: IntegrationModel = None
-    segment_config: IntegrationModel = None
-    mixpanel_config: IntegrationModel = None
-    heap_config: IntegrationModel = None
-    dynatrace_config: IntegrationModel = None
-    webhook_config: WebhookModel = None
-    hide_disabled_flags: bool = None
+    amplitude_config: typing.Optional[IntegrationModel] = None
+    dynatrace_config: typing.Optional[IntegrationModel] = None
+    heap_config: typing.Optional[IntegrationModel] = None
+    mixpanel_config: typing.Optional[IntegrationModel] = None
+    rudderstack_config: typing.Optional[IntegrationModel] = None
+    segment_config: typing.Optional[IntegrationModel] = None
+
+    webhook_config: typing.Optional[WebhookModel] = None
 
     _INTEGRATION_ATTS = [
         "amplitude_config",
-        "segment_config",
-        "mixpanel_config",
         "heap_config",
-        "dynatrace_config",
+        "mixpanel_config",
+        "rudderstack_config",
+        "segment_config",
     ]
 
     @property
-    def integrations_data(self) -> dict:
+    def integrations_data(self) -> typing.Dict[str, typing.Dict[str, str]]:
         """
         Return a dictionary representation of all integration config objects.
 
             e.g.
             {
-                "mixpanel_configuration": {"base_url": None, "api_key": "some-key"},
-                "segment_configuration": {
+                "mixpanel_config": {"base_url": None, "api_key": "some-key"},
+                "segment_config": {
                     "base_url": "https://api.segment.com",
                     "api_key": "some-key",
                 }
