@@ -19,6 +19,7 @@ PERCENTAGE_SPLIT = "PERCENTAGE_SPLIT"
 MODULO = "MODULO"
 IS_SET = "IS_SET"
 IS_NOT_SET = "IS_NOT_SET"
+IN = "IN"
 
 CONDITION_OPERATORS = [
     EQUAL,
@@ -34,4 +35,5 @@ CONDITION_OPERATORS = [
     MODULO,
     IS_SET,
     IS_NOT_SET,
+    IN,
 ]
